netapp_ontap.models.metrocluster_diag_connection API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.metrocluster_diag_connection`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class MetroclusterDiagConnectionSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the MetroclusterDiagConnection object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `destination_address: str GET`

    The destination_address field of the metrocluster_diag_connection.

  `partner: MetroclusterPartner GET POST PATCH`

    The partner field of the metrocluster_diag_connection.

  `port: str GET`

    The port field of the metrocluster_diag_connection.

  `result: str GET`

    Result of the diagnostic operation on this component.

    Valid choices:

    - ok
    - warning
    - not_run
    - not_applicable
  `source_address: str GET`

    The source_address field of the metrocluster_diag_connection.

  `state: str GET`

    The state field of the metrocluster_diag_connection.

    Valid choices:

    - disconnected
    - completed
    - pinging_partner_nodes
    - enabling_ip_ports
    - connecting_to_storage
    - disconnecting_from_storage
    - disabling_ip_ports
    - configuring_ip_addresses
    - updating_node_roles
    - connecting_to_mediator
    - disconnecting_from_mediator